<?php

/**
 * Plugin Name: Display Post Excerpt or Image
 * Description: Choose to display post excerpt or image on single post via edit panel
 * Plugin URI: http://www.ckmacleod.com/plugins/display-post-excerpt-or-image/
 * Version:     1.0
 * Author:      CK MacLeod
 * Author URI:  http://www.ckmacleod.com/
 * License:     GPL
 * Text Domain: display-post-metabox
 * Domain Path: /languages
 */

/* FUNCTION TO INCLUDE IN THEME AFTER DEFINING POST-META 
*/
function display_image_with_single_post() {

	$include_featured = get_post_meta(get_the_ID(), '_include_featured', true );
	
	if ( $include_featured == 1 ) {
	
	if ( has_post_thumbnail() ) { ?>
		<div class="entry-thumbnail">
			<?php the_post_thumbnail( 'large' ); ?>
		</div>
		<?php }
	}
}

/* FUNCTION TO INCLUDE IN THEME AFTER DEFINING POST-META 
*/

function display_excerpt_with_single_post() {

	$include_excerpt = get_post_meta( get_the_ID(), '_include_excerpt', true );
	
	if ( $include_excerpt == 1 ) {
	?>

	<div class="entry-excerpt">
		 <?php the_excerpt();?>
	</div>
		<?php 
	}
}

/**
 * Adds a box to the main column on the Post and Page edit screens.
 */
function post_display_metabox() {

    add_meta_box(
       'post_display_meta_box', 
			'Layout', 'post_display_meta_box_callback', 'post', 'side' ,
		 'high'
    );
}

add_action( 'add_meta_boxes', 'post_display_metabox' );

/**
 * Prints the box content.
 * 
 * @param WP_Post $post The object for the current post/page.
 */
function post_display_meta_box_callback( $post ) {

    // Add a nonce field so we can check for it later.
    wp_nonce_field( 'post_display_metabox_data', 'post_display_meta_box_nonce' );

    /*
     * Use get_post_meta() to retrieve an existing value
     * from the database and use the value for the form.
     */
    $include_featured = get_post_meta( $post->ID, '_include_featured', true );
    $include_excerpt =  get_post_meta( $post->ID, '_include_excerpt', true );

/*
     * EDITED UP TO HERE - NEED EXACT CODE FOR CHECKBOX BUTTONS
     */	

    ?>
    <div id="post-display-meta-labels">
        <div id="post-display-meta-excerpt" class="post-display-meta-div">
            <label for="post-display-meta-excerpt">
                <input type="checkbox" name="_include_excerpt" id="display-excerpt-checkbox" value="1" <?php if ( isset ( $include_excerpt ) ) { checked( $include_excerpt, '1' ); } ?> />
                    <?php _e( 'Show Post Excerpt after Post Title', 'post_display_meta_box' )?>
            </label>
        </div>
        <div id="post-display-meta-featured" class="post-display-meta-div">
        <label for="post-display-meta-featured">
            <input type="checkbox" name="_include_featured" id="display-featured-checkbox" value="1" <?php if ( isset ( $include_featured ) ) { checked( $include_featured, '1' ); } ?> />
                    <?php _e( 'Show Full-Width Version of Featured Image before Post Content ', 'post_display_meta_box' )?>
        </label>
        </div>
    </div>
		
<?php }

/**
 * When the post is saved, saves our custom data.
 *
 * @param int $post_id The ID of the post being saved.
 */
function post_display_save_meta_box_data( $post_id ) {

	/*
	 * We need to verify this came from our screen and with proper authorization,
	 * because the save_post action can be triggered at other times.
	 */

	// Check if our nonce is set.
	if ( ! isset( $_POST['post_display_meta_box_nonce'] ) ) {
		return;
	}

	// Verify that the nonce is valid.
	if ( ! wp_verify_nonce( $_POST['post_display_meta_box_nonce'], 'post_display_metabox_data' ) ) {
		return;
	}

	// If this is an autosave, our form has not been submitted, so we don't want to do anything.
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
		return;
	}

	// Check the user's permissions.
	if ( isset( $_POST['post_type'] ) && 'page' == $_POST['post_type'] ) {

		if ( ! current_user_can( 'edit_page', $post_id ) ) {
			return;
		}

	} else {

		if ( ! current_user_can( 'edit_post', $post_id ) ) {
			return;
		}
	}

	/* OK, it's safe for us to save the data now. */
	
	// Make sure that it is set.
	if ( ! isset( $_POST['_include_excerpt'] ) ) {
	    update_post_meta($post_id,'_include_excerpt', 0);
	} else {
            update_post_meta($post_id,'_include_excerpt', 1);
        }
	
	if ( ! isset( $_POST['_include_featured'] ) ) {
            update_post_meta($post_id,'_include_featured', 0);
	} else {
            update_post_meta($post_id,'_include_featured', 1);
        }

	/*/* Sanitize user input.
	// PROPER FORMAT FO CHECKBOX RESULT?
	$include_excerpt_box = $_POST['_include_excerpt'] ;
	$include_featured_box = $_POST['_include_featured'] ;

	// Update the meta field in the database.
	update_post_meta( $post_id, '_include_excerpt', $include_excerpt_box );
	update_post_meta( $post_id, '_include_featured', $include_featured_box );
         * 
         */
}
add_action( 'save_post', 'post_display_save_meta_box_data' );

/****
 * to show page image - will need five part image (or could be actual text) title/excerpt/meta/image/text
 * function checkUncheck() { 
    $('.pChk').click(function() {
        if ( $('.pChk:checked').length > 0) {
            $("#ProjectListButton").show();
        } else {
            $("#ProjectListButton").hide();
        }
    }); 
}
to check if any of the checkboxes is checked (lots of checks in this line..).

reference: http://api.jquery.com/checked-selector/
 */

/*ENQUEUE STYLESHEET */

function display_meta_stylesheet() {
    wp_enqueue_style('display_meta_style', plugins_url('style.css',__FILE__));
}


add_action('wp_enqueue_scripts', 'display_meta_stylesheet');
add_action('admin_enqueue_scripts', 'display_meta_stylesheet');

