<?php

/*
 * @Package: Extraordinary Comments
 * @Plugin URI: http://ckmacleod.com/plugins/extraordinary-comments
 * @Since: 0.91
 * @Author: CK MacLeod
 * @Author URI: http://ckmacleod.com/
 * @License: GPL3, http://www.gnu.org/licenses/gpl.txt
 * Date: October 2016
 * 
*/

defined( 'ABSPATH' ) or die( 'Plugin file cannot be accessed directly.' ) ;

add_action( 'widgets_init', create_function( '', 
        'register_widget("Extraordinary_Comments_Widget") ;' ) ) ;

class Extraordinary_Comments_Widget extends WP_Widget {

    public function __construct() {

        parent::__construct(
                'cks_exc',
                __( 'Extraordinary Comments', 'cks_exc' ),
                array(
                        'classname'	=>  'cks_exc cks_exc-widget',
                        'description'	=>  __( 
                                'Display extraordinary comments.', 'cks_exc' )
                )
        ) ;

    } // end constructor
    
    public function cks_exc_widget_defaults() {
        
        $defaults = array(

            'title'             => __( 'Extraordinary '
                    . 'Comments', 'cks_exc' ),          //widget title
            'descr'             => '',           
            'number_comments'   => 5,                   //int, how many comments to show in a table
            'type'              => 'featured',     //what kind of comments to show in table
            'order'             => 'DESC',              //order in which to retrieve comments: ASC, DESC
            'rand'              => 1,                   //whether to display comments in random order
            'lookback'          => 'January 1, 1970',   //how far back to look for comments (readable date or expression)
            'lookforward'       => 'January 1, 2038',   //include only up to this date
            'add_link'          => 0,                   //whether to show a linkback to other category
            'link_label'        => 'View All &rarr;',   //what the link shows
            'link_url'          => esc_url( home_url( '/' ) ) 
                . 'extraordinary-comments/',            //link URL
            'gravatar_size'     => 60,                  //size in pixels of gravatar
            'excerpt_length'    => 25,                  //max-length of excerpt in words
            'pre_date'          => '',                  //prior to datetime
            'datetime_format'   => 'Y-m-d g:i a',        //datetime format - or string if not a valid datetime
            'pre_irt'           => __('To ', 'cks_exc'), //address for IRT
            'pre_title'         => __('', 'cks_exc'), //Pre-Title
            'continued_label'   => '[...]',             //label for link to full comment
            'show_credit'       => 0,                   //show CK's plug-ins link

        ) ;
        
        return $defaults ;
        
    } 

    /**
     * Outputs the content of the widget.
     *
     * @param	array	args		The array of form elements
     * @param	array	instance	The current instance of the widget
     */
    public function widget( $args, $instance ) {

        $cache = wp_cache_get( 'extraordinary_comments_widget', 'widget' ) ;

        if ( ! is_array( $cache ) )
                $cache = array() ;

        if ( ! isset( $args['widget_id'] ) )
                $args['widget_id'] = $this->id;

        if ( isset( $cache[ $args['widget_id'] ] ) ) {
                echo $cache[ $args['widget_id'] ];
                return;
        }

        $output = '' ;

        $defaults = $this->cks_exc_widget_defaults() ;

        $new_args = wp_parse_args( $instance, $defaults ) ;

        $args = wp_parse_args( $new_args, $args ) ;

        $keys = array_keys( $args ) ;

        foreach ( $keys as $option_name ) {

            $$option_name = isset( $args[$option_name]) ? $args[$option_name] : 
                '' ;

        }

    $query_args = apply_filters( 'extraordinary_comments_query', array(

        'number'        =>  '',
        'status'        =>  'approve',
        'post_status'   =>  'publish',
        'meta_query'    =>  array(
                                array(
                                    'key'    => $type,
                                    'value'  => '1'
                                )
                            ),

        'order'         =>  $order,
        'date_query'    =>  array(

                                'after'     => $lookback,
                                'before'    => $lookforward,

                            ), 
        ) 

    ) ;

    $query    = new WP_Comment_Query;

    $comments = $query->query( $query_args ) ;
    
    if( $comments ) {

        if ( $rand ) {

            $comments = cks_exc_shuffle_assoc( $comments ) ;

        }
        
    if ( $number_comments ) {
        
        $comments = array_slice( $comments, 0, $number_comments ) ;
        
    }

        $output = $args['before_widget'];

        $output .= $args['before_title'] 
                    . apply_filters( 'cks_exc_widget_title', $title) 
                    . $args['after_title'] ;
        
        #$output .= '<div class="cks_exc cks_exc-widget">' ;
        
        if ( $descr ) {
        
            $output .= '<p class="cks_exc-widget-descr">' . $descr . '</p>' ;
            
        }
        
        do_action( 'cks_exc_widget_comments_before', $args ) ;

        $output .= '<ul class="cks_exc-comments cks_exc-comments-widget">' ;

        foreach ( (array) $comments as $comment) {
            
            do_action( 'cks_exc_widget_comment_before', $comment ) ; 
            
            $output .= '<li class="cks_exc-comment cks_exc-comment-widget">' ;
            
            $output .= '<div class="cks_exc-comment-header '
                    . 'cks_exc-comment-header-widget">' ;
            
            $output .= cks_exc_comment_datetime( 
                    $comment, $pre_date, $datetime_format  
                    ) ;
            
            $output .= cks_exc_in_reply_to( $comment, $pre_irt ) ;  
            
            $output .= '<div class="cks_exc-post-title">' ;
            
            $output .= '<span class="cks_exc-pre-title">' . $pre_title 
                    . '</span>' ;
            
            $output .= '<a href="' . get_permalink( $comment->comment_post_ID) 
                    . '">' 
                    . apply_filters( 
                            'cks_exc_widget_post_title', 
                            get_the_title( $comment->comment_post_ID ) ) 
                    . '</a>' ;
            
            $output .= '</div><!--end post title-->' ;
            
            $output .= '<div class="comment-author cks_exc-comment-author">' ;
            
            if ( 0 !== $gravatar_size ) {

                $output .=  get_avatar( $comment->comment_author_email, 
                                $gravatar_size) ;

            }
            
            $output .= '<span class="cks_exc-comment-author-name">' ;
            
            $output .= apply_filters( 'cks_exc_widget_author-link', 
                        get_comment_author_link( 
                                $comment->comment_ID ), $comment ) ;
            
            $output .= '</span><!--end author name-->' ;
            
            $output .= '</div><!--end author-->' ;
            
            $output .= '</div><!--end header-->' ; //END COMMENT HEAD
            
            $output .= '<div class="comment-body cks_exc-comment-body" '
                    . 'id="text-' . $comment->comment_ID . '">' ; 
            			
            $output .= cks_exc_get_exc_comment_text( 
                        $comment, $excerpt_length, $continued_label ) ;
            
            $output .= '</div>' ; //END COMMENT BODY
            
            $output .= '</li>' ; 
            
            do_action( 'cks_exc_widget_comment_after', $comment ) ; 
                
        } //foreach

        } //if $comments

            $output .= '</ul>' ;  //END LIST
            
            do_action( 'cks_exc_widget_comments_after', $args ) ;

            if ( $add_link ) {

                $output .= '<div class="cks_exc-footer '
                        . 'cks_exc-footer-widget">' ;
                
                $output .=  '<a class="cks_exc-linkback '
                            . 'cks_exc-linkback-widget" ' . 'href="' 
                            . $link_url . '">' ;
                
                $output .= apply_filters( 'cks_exc-widget-link-label', 
                            $link_label ) . '</a>' ;
                
                $output .= '</div>' ;
                
            }
            
            $output .= cks_cfix_add_credit( $show_credit ) ;

            #$output .= '</div>'; // cks_exc-comments cks_exc-widget

            $output .= $args['after_widget'] ;

            echo apply_filters( 'cks_exc_widget_html', $output ) ;

            $cache[$args['widget_id']] = $output ;
            wp_cache_set( 'extraordinary_comments_widget', $cache, 'widget' ) ;

    } // end widget


    /**
     * Processes the widget's options to be saved.
     *
     * @param	array	old_instance	The previous instance of values before the update.
     * @param	array	new_instance	The new instance of values to be generated via the update.
     */
    public function update( $new_instance, $old_instance ) {

            $instance = $old_instance;
//
            $instance['title']              = sanitize_text_field( 
                    $new_instance['title'] ) ;
            $instance['descr']              = esc_html( 
                    $new_instance['descr'] ) ;
            $instance['number_comments']    = absint( 
                    $new_instance['number_comments'] ) ;
            $instance['order']              = sanitize_text_field( 
                    $new_instance['order'] ) ;
            $instance['rand']      = absint( 
                    $new_instance['rand'] ) ;
            $instance['type']               = sanitize_text_field( 
                    $new_instance['type'] ) ;
            $instance['lookback']           = sanitize_text_field( 
                    $new_instance['lookback'] ) ;
            $instance['lookforward']           = sanitize_text_field( 
                    $new_instance['lookforward'] ) ;
            $instance['link_label']         = sanitize_text_field( 
                    $new_instance['link_label'] ) ;
            $instance['add_link']      =  
                    isset( $new_instance['add_link'] ) ? absint( 
                    $new_instance['add_link'] ) : '' ;
            $instance['link_url']           = 
                    $new_instance['link_url'] ;
            $instance['gravatar_size']      = absint( 
                    $new_instance['gravatar_size'] ) ;
            $instance['excerpt_length']     = absint( 
                    $new_instance['excerpt_length'] ) ;
            $instance['pre_date']         = esc_html( 
                    $new_instance['pre_date'] ) ;
            $instance['datetime_format']         = sanitize_text_field( 
                    $new_instance['datetime_format'] ) ;
            $instance['pre_irt']         = esc_html( 
                    $new_instance['pre_irt'] ) ;
            $instance['pre_title']         = esc_html( 
                    $new_instance['pre_title'] ) ;
            $instance['continued_label']         = esc_html( 
                    $new_instance['continued_label'] ) ;
            $instance['show_credit']      =  
                    isset( $new_instance['show_credit'] ) ? absint( 
                    $new_instance['show_credit'] ) : '' ;
            
            wp_cache_delete( 'extraordinary_comments_widget', 'widget' ) ;

            return $instance;

    } // end widget


    /**
     * Generates the administration form for the widget.
     *
     * @param	array	instance	The array of keys and values for the widget.
     */
    public function form( $instance ) {

        $defaults = $this->cks_exc_widget_defaults() ;
        
        if ( $this->number == '__i__' ) {

         $widget_identifier = 'Save Widget to get ID#' ;

            } else {

         $widget_identifier = '#' . $this->id  ;

        }

        $args = wp_parse_args( $instance, $defaults ) ;

        $keys = array_keys( $defaults ) ;

        foreach ( $keys as $option_name ) {

            $$option_name = isset( $args[$option_name]) ? $args[$option_name] : 
                '' ;
            
        }
        
    ?>

        <h4 id="<?php echo $this->get_field_id( 'title' ) ; ?>"><?php _e( 'Widget Title:', 'cks_exc' ) ; ?></h4>
        <p>
            <input style="width: 50%" class="" id="<?php echo $this->get_field_id( 'title' ) ; ?>" name="<?php echo $this->get_field_name( 'title' ) ; ?>" type="text" value="<?php echo esc_html( $title ) ; ?>" />
        </p>
        <h4 id="<?php echo $this->get_field_id( 'title' ) ; ?>"><?php _e( 'Subtitle/Description', 'cks_exc' ) ; ?></h4>
        <p>
            <textarea rows="2" style="font-family:Consolas,Monaco,monospace;width:100%;" name="<?php echo $this->get_field_name( 'descr' ) ; ?>" ><?php echo esc_html( $descr ) ; ?></textarea>
        </p>
        <h4 id="<?php echo $this->get_field_id( 'number_comments' ) ; ?>"><?php _e( 'Number of Comments to Show', 'cks_exc' ) ; ?></h4>
        <p>
            <input style="width:50px;" id="<?php echo $this->get_field_id( 'number_comments' ) ; ?>" name="<?php echo $this->get_field_name( 'number_comments' ) ; ?>" type="number" value="<?php echo esc_attr( $number_comments ) ; ?>" />
        </p>
        <h4 id="<?php echo $this->get_field_id( 'type' ) ; ?>"><?php _e( 'Type of Comment:', 'cks_exc' ) ; ?></h4>
        <p>
            <input class="" id="<?php echo $this->get_field_id( 'type' ) ; ?>" name="<?php echo $this->get_field_name( 'type' ) ; ?>" type="radio" value="featured" <?php if ( $type === 'featured' ) { echo 'checked="checked"' ; } ?>/><label for="<?php echo $this->get_field_id( 'order' ) ; ?>-extra"><?php _e( 'Show Extraordinary (Featured) Comments', 'cks_exc' ) ; ?></label><br>
            <input class="" id="<?php echo $this->get_field_id( 'type' ) ; ?>" name="<?php echo $this->get_field_name( 'type' ) ; ?>" type="radio" value="buried" <?php if ( $type === 'buried' ) { echo 'checked="checked"' ; } ?>/><label for="<?php echo $this->get_field_id( 'order' ) ; ?>-buried"><?php _e( 'Show Buried Comments', 'cks_exc' ) ; ?></label>
        </p>
        <h4 id="<?php echo $this->get_field_id( 'order' ) ; ?>"><?php _e( 'Order:', 'cks_exc' ) ; ?></h4>
        <p>
            <input class="" id="<?php echo $this->get_field_id( 'order' ) ; ?>-asc" name="<?php echo $this->get_field_name( 'order' ) ; ?>" type="radio" value="ASC" <?php if ( $order === 'ASC' ) { echo 'checked="checked"' ; } ?>/><label for="<?php echo $this->get_field_id( 'order' ) ; ?>-asc"><?php _e( 'Retrieve Comments in ascending (chronological) order.', 'cks_exc' ) ; ?></label><br>
            <input class="" id="<?php echo $this->get_field_id( 'order' ) ; ?>-desc" name="<?php echo $this->get_field_name( 'order' ) ; ?>" type="radio" value="DESC" <?php if ( $order === 'DESC' ) { echo 'checked="checked"' ; } ?> /><label for="<?php echo $this->get_field_id( 'order' ) ; ?>-asc"><?php _e( 'Retrieve Comments in decending (reverse chronological) order.', 'cks_exc' ) ; ?></label>
        </p>
        <p>
            <input class="" id="<?php echo $this->get_field_id( 'rand' ) ; ?>-random" name="<?php echo $this->get_field_name( 'rand' ) ; ?>" type="checkbox" value=1 <?php if ( $rand === 1 ) { echo 'checked="checked"' ; } ?> /><label for="<?php echo $this->get_field_id( 'order' ) ; ?>-rand"><?php _e( 'Show Random Selection of Retrieved Comments.', 'cks_exc' ) ; ?></label>
        </p>
        <h4 id="<?php echo $this->get_field_id( 'title' ) ; ?>"><?php _e( 'Include Comments After:', 'cks_exc' ) ; ?></h4>
        <p>
            <input class="" id="<?php echo $this->get_field_id( 'lookback' ) ; ?>" name="<?php echo $this->get_field_name( 'lookback' ) ; ?>" type="text" value="<?php echo esc_html( $lookback ) ; ?>" />
        </p>
        <h4 id="<?php echo $this->get_field_id( 'title' ) ; ?>"><?php _e( 'Include Comments Until:', 'cks_exc' ) ; ?></h4>
        <p>
            <input class="" id="<?php echo $this->get_field_id( 'lookforward' ) ; ?>" name="<?php echo $this->get_field_name( 'lookforward' ) ; ?>" type="text" value="<?php echo esc_html( $lookforward ) ; ?>" />
        </p>
        <h4 id="widget-contents" ><?php _e( 'Elements', 'cks_exc' ) ; ?></h4><p>
            <input class="" id="<?php echo $this->get_field_id( 'pre_date' ) ; ?>" name="<?php echo $this->get_field_name( 'pre_date' ) ; ?>" type="text" value="<?php echo esc_html( $pre_date ) ; ?>" /> <label for="<?php echo $this->get_field_id( 'pre_date' ) ; ?>"><?php _e( 'Before Comment Date/Time', 'cks_exc' ) ; ?></label>
        </p>
        <p>
            <input class="" id="<?php echo $this->get_field_id( 'datetime_format' ) ; ?>" name="<?php echo $this->get_field_name( 'datetime_format' ) ; ?>" type="text" value="<?php echo esc_html( $datetime_format ) ; ?>" /> <label for="<?php echo $this->get_field_id( 'datetime_format' ) ; ?>"><?php _e( 'Comment Datetime Format', 'cks_exc' ) ; ?></label><br><span class="description"><?php printf( __( 'Use a PHP datetime format (the default), or %sescaped string%s', 'cks_exc'), '<a href="http://php.net/manual/en/function.date.php/#example-2565" target="_blank" >', '</a>') ; ?>.</span>
        </p>
        <p>
            <input class="" id="<?php echo $this->get_field_id( 'pre_irt' ) ; ?>" name="<?php echo $this->get_field_name( 'pre_irt' ) ; ?>" type="text" value="<?php echo esc_html( $pre_irt ) ; ?>" /> <label for="<?php echo $this->get_field_id( 'pre_irt' ) ; ?>"><?php _e( 'Before In-Reply-To Name', 'cks_exc' ) ; ?></label>
        </p>
        <p>
            <input class="" id="<?php echo $this->get_field_id( 'pre_title' ) ; ?>" name="<?php echo $this->get_field_name( 'pre_title' ) ; ?>" type="text" value="<?php echo esc_html( $pre_title ) ; ?>" /> <label for="<?php echo $this->get_field_id( 'pre_title' ) ; ?>"><?php _e( 'Before Post Title', 'cks_exc' ) ; ?></label>
        </p>
        <p>
            <input style="width:50px;" id="<?php echo $this->get_field_id( 'gravatar_size' ) ; ?>" name="<?php echo $this->get_field_name( 'gravatar_size' ) ; ?>" type="number" value="<?php echo esc_attr( $gravatar_size ) ; ?>" />
            <label for="<?php echo $this->get_field_id( 'gravatar_size' ) ; ?>"><?php _e( 'Gravatar Size', 'cks_exc' ) ; ?></label><br><span class="description"><?php printf( __( 'Will be overriden in many themes - see "Widget Customization" in %sADD CSS%s', 'cks_exc'), '<a href="' . admin_url('options-general.php?page=cks_exc') . '">', '</a>' ) ; ?></a>.</span>
        </p>
        <p>
            <input style="width:50px;" id="<?php echo $this->get_field_id( 'excerpt_length' ) ; ?>" name="<?php echo $this->get_field_name( 'excerpt_length' ) ; ?>" type="number" value="<?php echo esc_attr( $excerpt_length ) ; ?>" />
            <label for="<?php echo $this->get_field_id( 'excerpt_length' ) ; ?>"><?php _e( 'Length of Excerpt in Words', 'cks_exc' ) ; ?></label>
        </p>
        <p>
            <input class="" id="<?php echo $this->get_field_id( 'continued_label' ) ; ?>" name="<?php echo $this->get_field_name( 'continued_label' ) ; ?>" type="text" value="<?php echo esc_html( $continued_label ) ; ?>" /> <label for="<?php echo $this->get_field_id( 'continued_label' ) ; ?>"><?php _e( 'Label for Link to Full Comment', 'cks_exc' ) ; ?></label>
        </p>
        <h4 id="widget-links-title"><?php _e( 'Bottom Linkback', 'cks_exc' ) ; ?></h4>
        <p>
            <input id="<?php echo $this->get_field_id( 'add_link' ) ; ?>" name="<?php echo $this->get_field_name( 'add_link' ) ; ?>" type="checkbox" value="1" <?php if ( $add_link === 1 ) { echo 'checked="checked"' ; } ?>/>
            <label for="<?php echo $this->get_field_id( 'add_link' ) ; ?>"><?php _e( 'Add a Link to Another Page?', 'cks_exc' ) ; ?></label>
        </p>
        <p>
            <label for="<?php echo $this->get_field_id( 'link_label' ) ; ?>"><?php _e( 'Link Label:', 'cks_exc' ) ; ?></label>
            <input style="width: 50%;" id="<?php echo $this->get_field_id( 'link_label' ) ; ?>" name="<?php echo $this->get_field_name( 'link_label' ) ; ?>" type="text" value="<?php echo esc_html( $link_label ) ; ?>" />
        </p>
        <p>
            <label for="<?php echo $this->get_field_id( 'link_url' ) ; ?>"><?php _e( 'Link URL:', 'cks_exc' ) ; ?></label>
            <input class="widefat" id="<?php echo $this->get_field_id( 'link_url' ) ; ?>" name="<?php echo $this->get_field_name( 'link_url' ) ; ?>" type="text" value="<?php echo esc_html( $link_url ) ; ?>" />
        </p>
        <p>
            <label for="<?php echo $this->get_field_id( 'show_credit' ) ; ?>">
            <?php _e( 'Show a credit-link to plugins home page?' , 'cks_exc' ) ; ?>			
            <input type="checkbox" name="<?php echo $this->get_field_name( 'show_credit' ) ; ?>"
                <?php checked( $show_credit, 1 ) ; ?> value="1" /> 
            </label><br><?php _e( 'Like this: ', 'cks_exc' ) ; ?><img style="background-color: #FFF; border: 1px solid gray; opacity: .4; padding: 0 6px; vertical-align: text-bottom;" src="<?php echo plugins_url( 'images/cks_wp_plugins_80x16.jpg', __FILE__ ) ; ?>" ><br><small><i><?php _e( '(Nice way to thank the developer!)' , 'cks_exc' ) ; ?></i></small>
        </p>
        <p style="text-align: right"><b><?php _e( 'Widget ID (used in CSS): ', 'cks_exc' ) ; ?></b><?php echo $widget_identifier ; ?></p>

            <?php

    } // end form

} // end class
