<?php

/* 
 * OUTPUT THE HTML FOR LINK-POSTS TABLES
 * LINK-POSTS AGGREGATOR
 * Author: CK MacLeod
 * Version: 0.995
 * Date: September 2016
 */

defined( 'ABSPATH' ) or die( 'Plugin file cannot be accessed directly. ' ) ;

/**
 * GET CAT_ID AS SET OF NAMES CONVERTED INTO STRING OF IDS
 * used in linkpost query
 * @param string $cat_name
 * @return string
 */
function get_cat_id_string( $cat_name ) {
           
    $cat_arr = explode( ',', $cat_name ) ;

    foreach( $cat_arr as $cat ) {

        //escape html for html entities
        $cat_ids[] = get_cat_ID( esc_html( $cat ) ) ;

    }

    $cat_id = implode( ',', $cat_ids ) ;    

    return $cat_id ;

}

/**
 * Produces error message in Front End if category not set
 * @param array $instance - used as boolean true/false
 * different version for "template" vs "widget" versions
 */
function cks_lpa_no_cat( $instance ) {
    
    $create_category_link = '<a href="' . 
            esc_url(admin_url( 'edit-tags.php?taxonomy=category' ) ) . 
            '" />linkposts category</a>' ;
        
    $linkposts_settings_link = '<a href="' . 
            esc_url( admin_url( 
                    'options-general.php?page=cks_lpa&tab=main_settings' ) 
                    ) . '" />' . __( 'Linkposts Main Settings', 'cks_lpa') . '</a>' ;
    
    $widgets_link = '<a href="' . esc_url( admin_url( 'widgets.php' ) ) . '" />' . __( 'Widget Settings', 'cks_lpa' ) . '</a>';
    
    $template_link = '<a href="' . 
            esc_url( admin_url( 
                'options-general.php?page=cks_lpa&tab=installation_options' ) 
                ) . '" />' . 
                __( 'via template installation arguments', 'cks_lpa') . 
                '</a>' . __( ' (advanced users only).', 'cks_lpa')  ;
 
    if ( $instance ) {
    
        $error_message = sprintf( 
           __( '<p class="cks_lpa-error">'
                . 'You have to create a %1$s and designate it in %2$s! or %3$s</p>', 
                'cks_lpa' ), 
                $create_category_link, $linkposts_settings_link, $widgets_link ) ;
    } else {
        
        $error_message = sprintf( 
           __( '<p class="cks_lpa-error">'
                . 'You have to create a %1$s and designate it in %2$s or %3$s</p>', 
                'cks_lpa' ), 
                $create_category_link, $linkposts_settings_link, $template_link ) ;
    }
        
    return $error_message;
    
}

/**
 * Produces error message in Front End if category not set
 * for "shortcode" versions of table
 */
function cks_lpa_no_cat_sc() {
    
    $create_category_link = '<a href="' . 
            esc_url(admin_url( 'edit-tags.php?taxonomy=category' ) ) . 
            '" />linkposts category</a>' ;
        
    $linkposts_settings_link = '<a href="' . 
            esc_url(admin_url( 
                    'options-general.php?page=cks_lpa&tab=main_settings' ) 
                    ) . '" />Linkposts Main Settings</a>' ;
 
    $error_message = sprintf( 
       __( '<p class="cks_lpa-error">'
               . 'You have to create a %1$s and designate it in %2$s or via shortcode argument - <code>cat_name=<i>\'category name\'</i></code>!</p>', 
               'cks_lpa' ), $create_category_link, $linkposts_settings_link ) ;
        
    return $error_message;
    
}

/**
 * Produce no-posts-found error message on Front End if no posts in category
 * @param string $catname: must be set
 */
function cks_lpa_no_posts_found( $cat_name ) {
    
    $add_posts_link = '<a href="' . esc_url(admin_url( 'edit.php' ) ) . 
            '" />add posts</a>' ;
        
    $no_posts_message = sprintf( __( 
            '<p class="cks_lpa-error">No Posts Found '
            . 'in designated Link-Post category ("%2$s"): '
            . 'To display the Link-Posts Table, '
            . 'you must %1$s to the "%2$s" category or '
            . 'switch to a category with posts.</p>' , 'cks_lpa' ), 
            $add_posts_link, $cat_name 
            ) ;    
    
    return $no_posts_message;
    
}

/***
 * CONSTRUCT THE TABLE 
 * param string $table_name set when invoked but altered if widget or shortcode
 * param array $instance: settings from widget if present
 * param array $args: settings from args if present
 **/
function add_cks_lpa_table( $table_name = '', $instance, $args ) {
    
    //time execution
//    $exec_start_1 = 0 ;
//    $exec_end_1 = 0;
//    $exec_start_1 = microtime() ;
    
    $options = get_option( 'cks_lpa_settings' ) ;
    
    // "Advanced": Alter any and all options when emplacing add_table function.
    if ( $args ) {
        
        $options = array_merge( $options, $args ) ;
        
    }
    
    // Replace with widget-specific settings.
    if ( $instance ) { 
        
        $options = array_merge( $options, $instance ) ;
        
    }
    
    //Get all keys from options whether or not empty/set
    $keys = cks_lpa_array_keys();
    
    //Declare all variables (prevent notices for "undefined").
    foreach ( $keys as $option_name ) {
        
        $$option_name = ! empty( $options[$option_name]) ? $options[$option_name] : '' ;
        
    }
  
    //Convert category inclusions/exclusions to arrays.
    $exclude_array = cks_lpa_get_cats( $exclude_cat ) ;
    $include_array = ! empty(cks_lpa_get_cats( $include_cat ) ) ? 
            cks_lpa_get_cats( $include_cat ) : '' ;
    
    //Get category id names or if irrelevant/bypassed define as empty.
    if ( $no_lp_cat ) {
        
        $cat_name = '' ;
        $cat_id = '' ;
        
    } else {
        
        $cat_id = get_cat_id_string( $cat_name ) ;
        
        if ( empty( $cat_id ) ) {

            //Print error message and stop processing if needed category missing.
            echo cks_lpa_no_cat( $instance ) ; 
            return;

        }
            
    }
    
    /* MAIN LINK-POST QUERY */
    
    // Main link-post query args
    $query_args = array(
        
        'showposts'         => $number_posts,
        'post_status'       => 'publish',
        'cat'               => $cat_id,
        'category__not_in'  => $exclude_array,
        'category__in'      => $include_array,
        'order'             => $order,
        'orderby'           => $orderby,
            
    ) ;

    $my_query = new WP_Query( apply_filters( 
            'cks_lpa_table_query' , $query_args 
            ) ) ;
    
    if ( $my_query->have_posts() ) {

        ob_start() ;

        do_action( 'cks_lpa_before', $options ) ;
        
        echo '<div ' . cks_lpa_get_table_id( $instance, $table_name ) . 'class="' . cks_lpa_get_table_classes( $instance, $table_title, $no_quote ) . '">' ;

        if ( ! $hide_table_title ) {
            
            $title = '<h2 class="cks_lpa-table-title">' .  $table_title . '</h2>' ;
            
            echo apply_filters( 'cks_lpa_table_title' , $title ) ;
        
        }
        
        $new_date_array = array() ;

        //initialize counter variables
        $count = 0;

        while ( $my_query->have_posts() ) {

            $my_query->the_post() ;
            
            $old_date_array = $new_date_array ; 
            $new_date_array = cks_lpa_get_new_date( 
                    $day_group_format, $week_group_format, 
                    $month_group_format, $year_group_format 
                    ) ;

            ++$count;
            
            $lp_args = compact( 
                'table_name', 'cat_id', 'count', 
                'alt_plus', 'alt_minus', 'use_thumbnail', 'no_source_link', 
                    'hide_comments',
                'include_cat', 'exclude_from_list', 
                'hide_post_cats', 'hide_post_tags',
                'date_post', 'date_post_format',
                'no_quote',
                'use_excerpt', 'more_text', 'use_wp_excerpt', 'go_to_comments' 
            ) ;
            
            do_action( 'cks_lp_before_dates', $lp_args ) ;
            
            ob_start() ;
            
            echo cks_lp_compare_dates( 
                    $new_date_array, $old_date_array, $day_group, $week_group, 
                    $week_title, $month_group, $year_group 
                    ) ;

            /** 
             * THE LINKPOSTS: 
             * cks_lp_closed output displays in default, "closed" state
             * cks_lp_open output shows when "opened" via jQuery toggle
             */
            
            do_action( 'cks_lp_before', $lp_args ) ;
            
            if ( $instance ) {
                
                echo cks_lp_output_widget( $lp_args ) ;
                
            } else {
                
                echo cks_lp_output( $lp_args ) ;
            }
            
            $html = ob_get_clean() ;
            
            echo apply_filters( 'cks_lp', $html ) ;

            do_action( 'cks_lp_after', $lp_args ) ;

        } //endwhile

        //clean data (otherwise will pass variables from last $post object)
        wp_reset_query() ;
        
        //add linkbacks    
        $linkback_args = compact( 'cat_id', 'cat_name', 'show_right', 'cat_title', 'right_url', 
                'show_left', 'left_title', 'left_url' ) ;
        
        add_cks_linkbacks( $linkback_args ) ;
        
        //optional credit link
        if ( $show_credit ) { cks_lpa_add_credit() ; }

        echo '</div>' ; //LINKPOSTS TABLE COMPLETE
        
        do_action( 'cks_lpa_after', $options ) ;
        
//        //time execution
//        $exec_end_1 = microtime() ;
//        
//        $timetaken = $exec_end_1 - $exec_start_1 ;
//        
//        echo $timetaken ; 

        $html = ob_get_clean() ;

        return apply_filters( 'cks_lpa_table' , $html ) ;

    } else {
        
        do_action( 'cks_lpa_no_posts_found', $options ) ;

        echo cks_lpa_no_posts_found( $cat_name ) ;
        
    } #End Query
         
} 

/***
 * LINKPOSTS TABLE, SHORTCODE VERSION
 **/
add_shortcode( 'add_lt', 'add_cks_lpa_table_sc' ) ;

/***
 * CONSTRUCT THE TABLE - SHORTCODE VERSION 
 * param string $table_name set when invoked but altered if widget or shortcode
 * param array $instance: settings from widget if present
 * param array $atts: settings from shortcode if present
 **/
function add_cks_lpa_table_sc( $atts ) {
    
    //time execution
//    $exec_start_sc = microtime() ;

    $options = get_option( 'cks_lpa_settings' ) ;
    
    //get all keys from options whether or not empty/set
    $keys = cks_lpa_array_keys();
    
    //prevent notices for undefined variables
    foreach ( $keys as $option_name ) {
        
        $$option_name = ! empty( $options[$option_name]) ? $options[$option_name] : '' ;
        
    }
    
    /* SHORTCODE-ONLY VARIABLES, INITIALIZE */
    $date_query = array() ;
    $up_to_post_date = '' ;
    $table_date_legend = '' ;
    $paginate_table = '' ;
        
    extract( shortcode_atts(

        //could be condensed in same way other keys are
        array(

            'number_posts'          => $number_posts,
            'order'                 => $order,
            'orderby'               => $orderby,
            'table_title'           => $table_title,
            'hide_table_title'      => $hide_table_title,
            'no_source_link'        => $no_source_link,
            'alt_plus'              => $alt_plus,
            'alt_minus'             => $alt_minus,
            'use_thumbnail'         => $use_thumbnail,
            'use_excerpt'           => $use_excerpt,
            'more_text'             => $more_text,
            'use_wp_excerpt'        => $use_wp_excerpt,
            'hide_post_cats'        => $hide_post_cats,
            'hide_post_tags'        => $hide_post_tags,
            'hide_comments'         => $hide_comments,
            'cat_title'             => $cat_title,
            'show_right'            => $show_right,
            'left_title'            => $left_title,
            'show_left'             => $show_left,
            'exclude_cat'           => $exclude_cat,
            'include_cat'           => $include_cat,
            'exclude_from_list'     => $exclude_from_list,
            'right_url'             => $right_url,
            'left_url'              => $left_url,
            'date_post'             => $date_post,
            'date_post_format'      => $date_post_format,
            'day_group'             => $day_group,
            'day_group_format'      => $day_group_format,
            'week_group'            => $week_group,
            'week_group_format'     => $week_group_format,
            'week_title'            => $week_title,
            'month_group'           => $month_group,
            'month_group_format'    => $month_group_format,
            'year_group'            => $year_group,
            'year_group_format'     => $year_group_format,
            'show_credit'           => $show_credit,
            'no_lp_cat'             => $no_lp_cat,
            'no_quote'              => $no_quote,
            'cat_name'              => $cat_name,

            /* SHORTCODE ONLY VARIABLES */
            'table_id'              => '',                      //set specific id number or text to use in CSS Selectors
            'up_to_post_date'       => 0,                       //include only link-posts published prior to containing post's publication date 
            'datetime_format'       => 'l, F j, Y - g:i a',     //format for datetime, used automatically if up-to-post-date set, can be blank
            'datetime_before'       => '',                      //html to precede datetime text
            'paginate_table'        => 0,                       //whether to paginate the table: Works on Pages only 

        ), $atts )

    ) ;

    // for optional setting to show linkposts published only before containing post's published date
    if ( $up_to_post_date ) {

        global $post;

        $cut_off_datetime = $post->post_date ;

        $date_query = array( 

            'column' => 'post-date',
            'before' => $cut_off_datetime

        ) ;

        if ( $datetime_format ) {

            $table_date_html = '<h3 class="cks_lpa-table-date">'
                    . '<span class="cks_lpa-table-sc-date-before">' . 
                    $datetime_before . '</span>' . 
                    mysql2date( $datetime_format, $cut_off_datetime ) . 
                    '</h3>' ;
            
            $table_date_legend = apply_filters( 'lpa_table_date_legend', $table_date_html ) ;

       } 

    } 

    //If 'table_id' not set, use containing post ID for table ID.
    //If 'table_id' set, create sanitized string for ID.
    if ( empty( $table_id ) )   {

        global $post;

        $table_name = $post->ID;

    } else {
        
        $table_name_str = strtolower( sanitize_title_with_dashes( $table_id ) ) ;
        
        $table_name = apply_filters( 'lpa_table_name_sc', $table_name_str ) ;
        
    }

    //convert category inclusions/exclusions to arrays
    $exclude_array = cks_lpa_get_cats( $exclude_cat ) ;
    $include_array = cks_lpa_get_cats( $include_cat ) ;
    
    //get category id names for linkpost query and linkbacks      
    //produce error message unless set for no lp category (no_lp_cat)
    if ( $no_lp_cat ) {
        
        $cat_name = '' ;
        $cat_id = '' ;
        
    } else {
        
        $cat_id = get_cat_id_string( $cat_name ) ;
        
        if ( empty( $cat_id ) ) {

            echo cks_lpa_no_cat_sc() ; 
            return;

        }
            
    }
    
    //args for main linkposts query
    $query_args = array(
        
        'order'             => $order,
        'orderby'           => $orderby,
        'showposts'         => $number_posts,
        'post_status'       => 'publish',
        'cat'               => $cat_id,
        'category__not_in'  => $exclude_array,
        'category__in'      => $include_array,
        'date_query'        => $date_query,
            
    ) ;
    
     /* PAGINATION args */
    if ( is_page() && $paginate_table ) {

        $query_args = cks_lpa_add_query_args( $query_args, $number_posts ) ; 

    }

    //the linkposts query
    $my_query = new WP_Query( 
            apply_filters( 'cks_lpa_table_query_sc' , $query_args ) 
            ) ;
    
    if ( $my_query->have_posts() ) {
        
        do_action( 'cks_lpa_before_sc', $atts ) ;

        ob_start() ;

        $table_id = 'cks_lpa-table-' . $table_name ;
        echo '<div id="' . $table_id . '" class="cks_lpa-table cks_lpa-table-sc' . 
                ( $no_quote ? ' cks_lpa-table-no-quote' : '' ) . '">' ;

        if ( ! $hide_table_title ) {
            
            $title = '<h2 class="cks_lpa-table-title">' .  $table_title . 
                    '</h2>' ;
            
            echo apply_filters( 'cks_lpa_table_title_sc' , $title ) ;
        
        }
        
        echo $table_date_legend ; 

        //initialize counter variables
        $count = 0;
        
        $new_date_array = array() ;
        
        while ( $my_query->have_posts() ) {

            $my_query->the_post() ;
            
            $old_date_array = $new_date_array ; 
            $new_date_array = cks_lpa_get_new_date( 
                    $day_group_format, $week_group_format, 
                    $month_group_format, $year_group_format 
                    ) ;

            $source_link = cks_lpa_get_source_link( $no_source_link ) ;

            ++$count;
            
            $lp_args = compact( 'table_name', 'cat_id', 'count', 
                'alt_plus', 'alt_minus', 'use_thumbnail', 'no_source_link', 
                'hide_comments', 'date_post', 'date_post_format',
                'include_cat', 'exclude_from_list', 'hide_post_cats', 'hide_post_tags',
                'use_excerpt', 'more_text', 'use_wp_excerpt', 'go_to_comments',
                'no_quote' ) ;
            
            do_action( 'cks_lp_before_dates_sc', $lp_args ) ;
            
            ob_start();
            
            echo cks_lp_compare_dates( 
                    $new_date_array, $old_date_array, 
                    $day_group, $week_group, $week_title, 
                    $month_group, $year_group 
                    ) ;

            /** 
             * THE LINKPOSTS: 
             * cks_lp_closed output displays in default, "closed" state
             * cks_lp_open output shows when "opened" via jQuery toggle
             */

            //make post_ID available for post data, $table_name to narrow function
            do_action( 'cks_lp_before_sc', $lp_args ) ;
            //echo $table_name . '</br> ' ; 
            //echo $count ; 

/** 
             * THE LINKPOSTS: 
             * cks_lp_closed output displays in default, "closed" state
             * cks_lp_open output shows when "opened" via jQuery toggle
             */
            
            echo cks_lp_output_sc( $lp_args ) ;
            
            $html = ob_get_clean() ;
            
            echo apply_filters( 'cks_lp_sc', $html ) ;
           
            //make post_ID available for post data, $table_name to narrow function
            do_action( 'cks_lp_after_sc', $lp_args ) ;

        } //endwhile
        
        //clean data (otherwise will pass variables from last $post object)
        wp_reset_query() ;
	
        $linkback_args = compact( 'cat_id', 'cat_name', 'show_right', 'cat_title', 'right_url', 
                'show_left', 'left_title', 'left_url' ) ;
        
        add_cks_linkbacks( $linkback_args ) ;

        //optional credit link
        if ( $show_credit ) { cks_lpa_add_credit() ; }

        echo '</div>' ; //LINKPOSTS TABLE COMPLETE
        
        //shortcode and pages only
        if ( is_page() && $paginate_table ) {
            
            $max_num_pages = $my_query->max_num_pages ;
            
            $pagination = cks_lpa_pagination( $max_num_pages ) ;
            
            do_action( 'cks_lpa_before_pagination', $table_name ) ;
            
            echo $pagination  ; 
            
        }

        do_action( 'cks_lpa_after_sc', $atts ) ;
        
        //time execution
//        $exec_end_sc = microtime() ;
//        
//        $timetaken = $exec_end_sc - $exec_start_sc ;
//        
//        echo $timetaken ; 
        
        $html = ob_get_clean() ;

        return apply_filters( 'cks_lpa_table_sc' , $html ) ;

    } else {
        
        do_action( 'cks_lpa_no_posts_found_sc', $atts ) ;

        echo cks_lpa_no_posts_found( $cat_name ) ;
        
    } #End Query
         
} 

/**
 * GET TABLE ID
 * if has unique ID from Widget or Assigned via Argument
 * @param array $instance - used as Boolean true/false
 * @param string $table_name from Widget or Argument
 * @return string
 */
function cks_lpa_get_table_id( $instance, $table_name ) {
    
    $table_id = '' ;
    
    //get table CSS ID if $table_name exists
    if ( $table_name ) {
    
        if ( $instance) { 
            
            // "-table" suffix differentiates from assigned widget ID
            $table_id = 'id="' . $table_name . '-table" ' ;

        } else {
            
            $table_id = 'id="cks_lpa-' . $table_name . '-table" ' ;
            
        }
        
    }
    
    return apply_filters( 'cks_lpa_table_id', $table_id ) ;

}

/**
 * GET TABLE CLASSES
 * @param array $instance - used as Boolean true/false
 * @param string $table_title from options
 * @return string
 */
function cks_lpa_get_table_classes( $instance, $table_title, $no_quote ) {
    
    $table_classes = 'cks_lpa-table' ;
    
    if ( $no_quote ) { 
        
        $table_classes .= ' cks_lpa-no-quote' ; 
    }
    
    $table_classes .= $instance ? ' cks_lpa-table-widget' : ' cks_lpa-table-template' ;
    
    if ( $table_title ) { 
        
        $table_suffix = strtolower( sanitize_title_with_dashes( $table_title ) ) ;
        
        $table_classes .= ' cks_lpa-table-' . $table_suffix ; 
        
    }
    
    return apply_filters( 'cks_lpa_table_classes', $table_classes ) ;
    
}

/**
 * WRAPPER FUNCTION TO OUTPUT CLOSED AND OPEN VERSIONS OF LINK-POST
 * IN SHORTCODE TABLES
 * @param array $lp_args
 */
function cks_lp_output_sc( $lp_args ) {
    
    ob_start();
   
    echo cks_lp_closed( $lp_args ) ;
    
    echo cks_lp_open( $lp_args ) ;
    
    $html = ob_get_clean() ;
    
    return apply_filters( 'cks_lp_output_sc', $html ) ;
    
}

/**
 * WRAPPER FUNCTION TO OUTPUT CLOSED AND OPEN VERSIONS OF LINK-POST
 * IN TEMPLATE TABLES
 * @param array $lp_args
 */
function cks_lp_output( $lp_args ) {
    
    ob_start();
   
    echo cks_lp_closed( $lp_args ) ;
    
    echo cks_lp_open( $lp_args ) ;
    
    $html = ob_get_clean() ;
    
    return apply_filters( 'cks_lp_output_template', $html ) ;
    
}

/**
 * WRAPPER FUNCTION TO OUTPUT CLOSED AND OPEN VERSIONS OF LINK-POST
 * IN WIDGET TABLES
 * @param array $lp_args
 */
function cks_lp_output_widget( $lp_args ) {
    
    ob_start();
   
    echo cks_lp_closed( $lp_args ) ;
    
    echo cks_lp_open( $lp_args ) ;
    
    $html = ob_get_clean() ;
    
    return apply_filters( 'cks_lp_output_widget', $html ) ;
    
}


/**
 * CREATE INDIVIDUAL LINKPOST IN "CLOSED" STATE
 * @param array $lp_args - set in cks_lpa_add_table or cks_lpa_add_table_sc
 */
function cks_lp_closed( $lp_args ) {
    
    global $post ;
    
    $has_add_lt_sc = FALSE ;
    
    extract( $lp_args );
    
    //avoid system crash for loop within a loop within a...
    //prevents display of text containing add_lt shortcode
    //sets post with "add_lt" to no source-link tho should be gratuitous
    if ( has_shortcode( $post->post_content, 'add_lt' ) || 
        has_shortcode( $post->post_excerpt, 'add_lt' ) ) {
                
        $has_add_lt_sc = TRUE ;
        $no_source_link = 1 ;
        $no_quote = 1;
                
    }
    
    $pid = $post->ID ;
    
    $source_link = cks_lpa_get_source_link( $no_source_link ) ;
    
    do_action( 'cks_lp_closed_before', $lp_args ) ; 
	
    ob_start() ;
        
    ?>
    <!--CLOSED DIV -->
    <div class="cks_lp cks_lp-closed <?php cks_lp_classes(
        $count, $hide_comments, $alt_plus, $alt_minus, $use_thumbnail, $no_quote, $has_add_lt_sc
        ); ?>">
        
        <?php $no_quote_suffix =  $no_quote ? '-no-quote' : '' ; ?>
        
        <div class="cks_lp-plus<?php echo $no_quote_suffix ; ?> cks_lp-plus-minus<?php echo $no_quote_suffix ; ?> ">

            <span class="cks_lp-plus-minus-link<?php echo $no_quote_suffix ; ?>" title="<?php 
            _e( 'Open', 'cks_lpa') ; ?>" ><?php 
            echo ( $alt_plus ) ? $alt_plus :  '' ; ?>
            </span>
        
        </div>
        
        <?php cks_lpa_add_thumbnail( $use_thumbnail, $source_link ) ; ?>
        
        <div class="cks_lp-title">
            
            <a class="cks_lp-title-link" href="<?php 
            echo $source_link ?>" title="<?php 
            _e( 'Go to ', 'cks_lpa' ) ; ?><?php 
            the_title_attribute() ?>" alt="<?php 
            the_title_attribute() ?>" /><?php the_title() ; ?></a>
        
        </div>

        <?php if ( ! $hide_comments ) { ?>
        
        <div class="cks_lp-comments" >

            <?php 
            
            $comments_off = '<span class="cks_lp-comments-off">' . 
                    __( 'Off', 'cks_lpa' ) . '</span>';
            
            comments_popup_link( __( '(0)', 'cks_lpa'), __( '(1)', 'cks_lpa'), 
                    '(%)', 'cks_lp-comments-link', 
                    apply_filters( 
                            'cks_lp_closed_comments_off_text', $comments_off 
                            ) 
                    ) ; 
            
            ?>

        </div>
        
        <?php } ?>
        
        <?php 

        if ( $date_post ) { 
            
            $post_date_output = mysql2date( 
                $date_post_format , $post->post_date 
                ) ;

            echo '<div class="cks_lp-post-date">' . 
            apply_filters( 'cks_lp_closed_post_date', $post_date_output ) . 
            '</div>';

        } ?>

        <div class="cks_lp-terms">

            <?php 
            
            if ( ! $hide_post_cats  ) { 
                
                $cat_list = cks_lp_cat_list( 
                        $cat_id, $include_cat, $exclude_from_list 
                        ) ; 
                
                echo '<span class="cks_lp-cats">' .                         
                    apply_filters( 'cks_lp_closed_cat_list', $cat_list ) .                         
                    '</span>' ;
                
            } 
            
            if ( ! $hide_post_tags  ) { 
                
                $tag_list = cks_lp_tag_list() ; 
                
                echo '<span class="cks_lp-tags">' . 
                     apply_filters( 'cks_lp_closed_tag_list', $tag_list ) . 
                     '</span>' ;
                
            } ?>
            
        </div>

    </div>
    <!--CLOSED DIV END-->
	
	<?php $html = ob_get_clean() ; ?>
	
	<?php return apply_filters( 'cks_lp_closed_html', $html ); ?>
    
<?php 

    do_action( 'cks_lp_closed_after', $lp_args ) ; 

}  

/**
 * CREATE INDIVIDUAL LINK-POSTS IN "OPEN" STATE
 * param array $lp_args - set in cks_lpa_add_table or cks_lpa_add_table_sc
 */
function cks_lp_open( $lp_args ) {
    
    global $post ;
    
    $pid = $post->ID ;
    
    //avoid system crash for loop within a loop within a...
    //prevents display of text containing add_lt shortcode
    if ( has_shortcode( $post->post_content, 'add_lt' ) || 
        has_shortcode( $post->post_excerpt, 'add_lt' ) ) {
                
        return ;
                
    }
    
    extract( $lp_args ) ;
    
    if ( $no_quote ) {
        
        return '' ;
    
    }
    
    $source_link = cks_lpa_get_source_link( $no_source_link ) ;
    
    do_action( 'cks_lp_open_before', $lp_args ) ; 
    
    ob_start();
    
    ?>
    <!--"FULL DIV"-->
    <div class="cks_lp cks_lp-open <?php cks_lp_classes($count, $hide_comments,
        $alt_plus, $alt_minus, $use_thumbnail, $no_quote, '' ) ; ?><?php 
    
    #echo $use_thumbnail ? ' with-thumb' : ' no-thumb' ; 
    ?>" id="cks_lp-quote-open-<?php echo 
         $table_name . '-' . $count ; ?>">
        
        <div class="cks_lp-minus cks_lp-plus-minus">

            <span class="cks_lp-plus-minus-link" title="<?php 
            _e( 'Close', 'cks_lpa') ; ?>"/><?php 
            echo ( $alt_minus ) ? $alt_minus : '' ; ?>
            </span>
        
        </div>
        
        <?php cks_lpa_add_thumbnail( $use_thumbnail, $source_link ) ; ?>
        
        <div class="cks_lp-title">
            
            <a class="cks_lp-title-link" href="<?php 
            echo $source_link ?>" title="<?php 
            _e( 'Go to', 'cks_lpa' ) ; ?><?php 
            the_title_attribute() ?>" alt="<?php 
            the_title() ?>" /><?php 
            the_title() ; ?>
            </a>
        
        </div>

        <?php if ( ! $hide_comments ) { ?>
        
        <div class="cks_lp-comments">
            
           <?php 
            
            $comments_off = '<span class="cks_lp-comments-off">' . 
                    __( 'Off', 'cks_lpa' ) . '</span>';
            
            comments_popup_link( 
                    __( '(0)', 'cks_lpa'), 
                    __( '(1)', 'cks_lpa'), 
                    '(%)', 
                    'cks_lp-comments-link', 
                    apply_filters( 'cks_lp_open_comments_off_text', $comments_off ) ) ; 
            
            ?>

        </div>
        
        <?php } ?>
        
        <?php 

        if ( $date_post ) { 
            
            $post_date_output = mysql2date( 
                $date_post_format , $post->post_date 
                ) ;

            echo '<div class="cks_lp-post-date">' . 
            apply_filters( 'cks_lp_open_post_date', $post_date_output ) . 
            '</div>';

        } ?>

        <div class="cks_lp-terms">

            <?php 
            
            if ( ! $hide_post_cats  ) { 
                
                $cat_list = cks_lp_cat_list( 
                        $cat_id, $include_cat, $exclude_from_list 
                        ) ; 
                
                echo '<span class="cks_lp-cats">' .                         
                    apply_filters( 'cks_lp_open_cat_list', $cat_list ) .                         
                    '</span>' ;
                
            } 
            
            if ( ! $hide_post_tags  ) { 
                
                $tag_list = cks_lp_tag_list() ; 
                
                echo '<span class="cks_lp-tags">' . 
                     apply_filters( 'cks_lp_open_tag_list', $tag_list ) . 
                     '</span>' ;
                
            } ?>

        </div>
        
        <div class="cks_lp-quote-open" >

            <?php if ( $use_wp_excerpt ) {
                
                $excerpt = the_excerpt() ;

                echo apply_filters( 'cks_lp_wp_excerpt', $excerpt );
                
            } else {   
                
                if ( $use_excerpt ) {
            
                    if ( $post->post_excerpt ) {  

                        $excerpt = $post->post_excerpt ;

                        $excerpt_oembedded = cks_lp_oembed( $excerpt ) ;

                        echo apply_filters( 'cks_lp_excerpt', $excerpt_oembedded );

                        echo '<p><a class="cks_lp-moretag" href="' . 
                                get_permalink($pid) . '" title="' . 
                                __( 'Read the rest of ', 'cks_lpa') . 
                                $post->post_title . '">' . $more_text . '</a></p>' ;

                    } else {

                    $content = $post->post_content ;
                    
                    $content_oembedded = cks_lp_oembed( $content ) ;

                    echo apply_filters( 'cks_lp_content', $content_oembedded ) ; 

                    }
                
                } else {         

                    $content = $post->post_content ;
                    
                    $content_oembedded = cks_lp_oembed( $content ) ;

                    echo apply_filters( 'cks_lp_content', $content_oembedded ) ;                 

                }
            
            }
 
            ?>
            
            <?php do_action( 'cks_lp_finish_quote', $lp_args ) ; ?>

            <?php if ( ! $hide_comments && comments_open( $pid ) ) : ?>
            
                <a href="<?php 
                echo get_permalink( $pid ) ; 
                ?>" class="cks_lp-comment-link-bottom" /><?php 
                echo apply_filters( 'cks_lp_go_to_comments_text', $go_to_comments ) ; 
                ?></a>
            
            <?php endif; ?>
                
            <span class="cks_lp-plus-minus-link cks_lp-minus-bottom" 
                  title="<?php _e( 'Close', 'cks_lpa' ) ; ?>" /><?php 
                  echo ( $alt_minus ) ? $alt_minus :  '' ; ?>
            </span>	

            </div> 

            <?php do_action( 'cks_lp_open_after', $lp_args ) ; ?>
        
    </div> 
    <!-- FULL DIV END -->
   
<?php 

    $html = ob_get_clean() ; 
    
    return apply_filters( 'cks_lp_open_html', $html ) ;

   # }

}
/**
 * SET CSS CLASSES FOR LINK-POSTS
 * @param int $count
 * @param boolean int $hide_comments
 * @param string $alt_plus
 * @param string $alt_minus
 * @param boolean int $use_thumbnail
 * @param boolean int $no_quote
 * @param boolean int $has_add_lt_sc
 */
function cks_lp_classes( $count, $hide_comments, $alt_plus, $alt_minus, $use_thumbnail, $no_quote, $has_add_lt_sc ) {
    
    $cat_classes = array() ;
    
    foreach ( get_the_category() as $category ) { 
        
        $cat_classes[] = $category->slug ; 
        
    }
    
    $classes = ( $count % 2) ? 'odd ' : 'even ' ; 
    $classes .= 'cks_lp-' . $count . ' ' ;  
    $classes .= implode(' ', $cat_classes) . ' ' ;
    $classes .= $hide_comments ? 'cks_lp-no-comments ' : '' ; 
    $classes .= $alt_plus ? 'alt-plus ' :  '' ;
    $classes .= $alt_minus ? 'alt-minus ' : '' ;
    $classes .= $use_thumbnail ? 'use-thumb ' : 'hide-thumb ' ;
    $classes .= $no_quote ? 'no-quote ' :  '' ;
    $classes .= has_post_thumbnail() ? 'has-thumb ' : 'has-no-thumb ' ;
    $classes .= $has_add_lt_sc ? 'has-add-lt-sc' : '' ;
    
    echo apply_filters( 'cks_lp_classes', $classes ) ;
    
}

/* TABLE OUTPUT UTILITIES */

/**
 * GET SOURCE LINK
 * finds last formatted link (if any ) in quoted content
 * and uses it for optional/default setting
 * uses post permalink (normal functionality) if no formatted link available
 * @param boolean $no_source_link link to link-post rather than source
 * @return url for Link-Post title in table
 */
function cks_lpa_get_source_link( $no_source_link ) {
    
    global $post; 
    
    $post_ID = $post->ID ;
    
    if ( ! $no_source_link) {

        $link_arr = array() ;  
        
        $content = $post->post_content ; 
        
        $html = new DOMDocument( null, 'UTF-8' ) ;
        
        @$html->loadHTML( $content ) ;
        
        foreach ( $html->getElementsByTagName( 'a' ) as $link ) {
            
            $link_arr[] = $link->getAttribute( 'href' ) ;
            
        }
        
        $source_link = ! empty( $link_arr ) ? esc_url( 
                end( $link_arr ) 
                ) : get_the_permalink( $post_ID ) ;	

    } else {

        $source_link = get_the_permalink( $post_ID ) ;
        
    }
            
    return apply_filters( 'cks_lp_source_link', $source_link ) ;
                
}

/**
 * CONVERT INCLUDE/EXCLUDE CATEGORY NAME STRING 
 * TO ARRAY OF CATEGORIES AND CHILDREN
 * @param string $cat_string
 * @return array
 */
function cks_lpa_get_cats( $cat_string ) {
    
    $ward = array() ; 
    
    if ( $cat_string ) {
     
    $cat_arr = explode( ',', $cat_string ) ;
    
    $litters = array() ;
    
    foreach ( $cat_arr as $cat_name ) {
        
        $cat = get_cat_ID( $cat_name ) ;
        
        $cats[] = $cat ; 
        
        $kittens =  get_term_children( $cat, 'category' ) ;
            
        $litters = array_merge( $kittens, $litters ) ;
        
    }
    
    $ward = array_merge( $litters, $cats ) ;
    
    }
    
    return $ward ;
    
}

/**
 * GETS LIST OF CATEGORIES
 * exclude Link-Post Category and, optionally, "include category"
 * @param string $cat_id
 * @param string $include_cat
 * @param int $exclude_from_list
 * return string
 */
function cks_lp_cat_list( $cat_id, $include_cat, $exclude_from_list ) {
    
    $categories = get_the_category() ;
    $category_list = '' ;
    $cat_id_arr = explode( ',', $cat_id ) ;
    $other_excluded = array() ;
    
    if ( $exclude_from_list ) {
        
        //need to find prior logic and include if available or re-write if necessary
        
        $other_excluded = cks_lpa_get_excluded_cats( $include_cat) ;
        
    }
    
    $i = 0;

    foreach ( $categories as $category ) {
        
        $new_id = $category->term_id ; 

        if ( ! in_array( $new_id, $cat_id_arr ) && ! in_array( $new_id, $other_excluded )  ) {
     
            $i++;
            $category_link = sprintf( 
                '<a href="%1$s" alt="%2$s" title="%3$s">%4$s</a>',
                esc_url( get_category_link( $category->term_id ) ),
                esc_attr( sprintf( __( 
                        'View all posts in %s', 'cks_lpa' ), $category->name ) 
                        ),
                esc_attr( sprintf( __( 
                        'View all posts in %s', 'cks_lpa' ), $category->name ) 
                        ),    
                esc_html( $category->name )
            ) ;
            $add_comma = ( $i > 1) ? ', ' : '' ;

            $category_list .= sprintf( 
                    esc_html__( $add_comma . '%s', 'cks_lpa' ), 
                    $category_link 
                    ) ;
        
        }
        
    }
    
    return $category_list ; 
    
}

/**
 * GET OTHER CATS TO BE EXCLUDED FROM CAT LIST
 * @param string $include_cat
 * @return array
 */
function cks_lpa_get_excluded_cats( $include_cat ) {
    
    $other_excluded = array();
    
    $include_cat_arr = explode( ',', $include_cat ) ;
    
    foreach ($include_cat_arr as $excluded_cat ) {
        
        $other_excluded[] = get_cat_ID( $excluded_cat ) ;        
        
    }
    
    return $other_excluded ;
       
}

/**
 * GET TAG LIST
 * returns tag-links
 * formatted in default CSS with preceding hash (#) signs
 */
function cks_lp_tag_list() {
    
    $tags = get_the_tags() ;
    $tag_list = '' ;

    if ( $tags ) {
        
        foreach ( $tags as $tag ) {
            
            $tag_link = sprintf( '<a href="%1$s" alt="%2$s" title="%3$s">%4$s</a>',
                esc_url( get_tag_link( $tag->term_id ) ),
                esc_attr( sprintf( __( 
                        'View all posts tagged %s', 'cks_lpa' ), 
                        $tag->name ) ),
                esc_attr( sprintf( __( 
                        'View all posts tagged %s', 'cks_lpa' ), 
                        $tag->name ) ),    
                esc_html( $tag->name )
            ) ;
            
            //prevents jam-up of tag links, especially problem in narrow displays:
            $tag_link .= ' ' ;
            
        $tag_list .= $tag_link;
    
        }
   
    }
    
    return $tag_list ;
    
}

/**
 * MAKE AUTO EMBEDS WORK IN EXCERPTS
 * @global object $wp_embed
 * @param string $excerpt
 * @return string
 */
function cks_lp_oembed( $html ) {
    
    global $wp_embed ;
    
    $new_html = $wp_embed->autoembed( wpautop( $html ) ) ;
    
    return $new_html ;
    
}

/** 
 * ADD OPTIONAL LINKBACKS TO TABLE FOOTER
 * @param array $linkback_args, set in cks_lpa_add_table or cks_lpa_add_table_sc
 */
function add_cks_linkbacks( $linkback_args ) {
    
    extract( $linkback_args ) ;
    
    $cat_link = '' ;
    
    //GET IDS and URLS FOR THE LINKBACKS
    
    //if single category used as link-posts category, use it
    //won't be numeric if multiple categories, instead will be string with comma
    if ( $cat_id && is_numeric( $cat_id ) ) { 
        
        $cat_link = get_category_link( $cat_id ) ; 
        
    } else {
        
        $cat_link = '' ;
        
    }
    if ( $right_url ) {
        
        $cat_link = $right_url ; 
        
    }
    
    do_action( 'cks_lpa_linkback_before', $linkback_args ) ;
    
    ?>	

        <!-- THE LEFT LINKBACK -->
        <div class="cks_linkback">
            
        <?php if ( $show_left && $left_url ): ?>
            
            <a class="cks_linkback-left" href="<?php 
            echo esc_url( $left_url) ; ?>" ><?php echo $left_title ; ?></a>
            
        <?php endif; ?>
        
        <!-- THE RIGHT LINKBACK -->
        <?php if ( $show_right && $cat_link ) : ?>
        
            <a class="cks_linkback-right" href="<?php 
            echo esc_url( $cat_link) ; ?>" ><?php echo $cat_title; ?></a>
        
        <?php endif; ?>
        
        </div>

<?php  

    do_action( 'cks_lpa_linkback_after', $linkback_args ) ;
  
}

/** 
 * ADD CK'S PLUGINS CREDIT
 * produces image-link styled to appear flush left, buttom
 */
function cks_lpa_add_credit() {
    
    ?>
        
    <div class="cks-plugins-credit">

        <a href="http://ckmacleod.com/wordpress-plugins/" title="CK's WP Plugins">

            <img src="<?php 
            echo plugin_dir_url( __FILE__ ) ; ?>images/cks_wp_plugins_80x16.jpg" 
            alt="CK's WP Plugins">

        </a>

    </div>
        
    <?php
    
}

/**
 * PAGINATION: ADJUST QUERY FOR MAIN LINK-POSTS TABLE
 * @param array $query_args
 * @param int $number_posts number of posts per page per setting
 * @return array
 */
function cks_lpa_add_query_args( $query_args, $number_posts ) {
        
    /* PAGINATION VARIABLES */
    $page = get_query_var( 'paged' ) ? get_query_var( 'paged' ) : 1 ;
    $offset = ( $page - 1) * $number_posts;

    $pagination_args = array(
        
        'offset'    => $offset,
        'number'    => $number_posts,
        'page'      => $page,

    ) ;

    $new_query_args = array_merge( $query_args, $pagination_args ) ;
    
    return $new_query_args;

}
    
/**
 * PAGINATION: ADD LINKS
 * @param int $max_num_pages
 */
 function cks_lpa_pagination( $max_num_pages ) {

    $pagination = '<div class="navigation pagination cks_lpa-pagination">' ;

    $current_page = max(1, get_query_var( 'paged' ) ) ;
    
    $prev_text_str = __( '&laquo; Previous', 'cks_lpa' ) ;
    $next_text_str = __( 'Next &raquo;', 'cks_lpa' ) ;
    
    $prev_text = apply_filters( 'cks_lpa_pagination_prev', $prev_text_str ) ;
    $next_text = apply_filters( 'cks_lpa_pagination_next', $next_text_str ) ;
    
    $pagination_arr = array(
        
        'base' => get_pagenum_link(1) . '%_%',
        'current' => $current_page,
        'total' => $max_num_pages,
        'prev_text' => $prev_text,
        'next_text' => $next_text,
        'end_size' => 1,
        'mid_size' => 1,
        
    ) ;
    
    $args = apply_filters( 'cks_lpa_pagination_args', $pagination_arr ) ;

    $pagination .= paginate_links( $args ) ;

    $pagination .= '</div>' ;
    
    return $pagination ;
    
 }   
 
 /* DATE-RELATED UTILITIES */
 
/**
 * GET ARRAY OF DATE INFORMATION FOR DATE HEADERS AND POST DATE
 * @param string $day_group_format
 * @param string $week_group_format
 * @param string $month_group_format
 * @param string $year_group_format
 * @return array
 */
function cks_lpa_get_new_date( $day_group_format, $week_group_format, 
        $month_group_format, $year_group_format ) {  
    
    global $post ;
    
    $postdate = strtotime( $post->post_date) ;
    
    $week = date( 'W', $postdate ) ;
    $year = date( 'Y', $postdate ) ;
    
    $week_start_and_end = cks_lpa_getStartAndEndDate(
            $week, $year, $week_group_format 
            ) ;
    
    $new_date_array = array( 
        
        'day'           =>  date( $day_group_format, $postdate ),
        'week'          =>  date( $week_group_format, $postdate ) ,
        'month'         =>  date( $month_group_format, $postdate ) , 
        'year'          =>  date( $year_group_format, $postdate ) ,
        'day_of_month'  =>  date( 'j', $postdate ) ,
        'day_of_week'   =>  date( 'w', $postdate ) ,
        'week_start'    =>  $week_start_and_end['week_start'],
        'week_end'      =>  $week_start_and_end['week_end'] ,
        'post_date'     =>  $postdate,
            
    ) ;
    
    return $new_date_array ; 
    
}

/**
 * CONSTRUCT DATE HEADERS
 * @param array $new_date_array
 * @param array $old_date_array
 * @param boolean int $day_group
 * @param boolean int $week_group
 * @param string $week_title
 * @param boolean int $month_group
 * @param boolean int $year_group
 */
function cks_lp_compare_dates( $new_date_array, $old_date_array, 
        $day_group, $week_group, $week_title, $month_group, $year_group ) { 
    
    $add_class = '' ;
    
    if ( empty( $old_date_array ) ) {
        
        $add_class = ' cks_lp-first-date-header' ;
        
    }
        
        $date_diff = array_diff( $new_date_array, $old_date_array ) ; 
        $date_group_header = '<div class="cks_lp-date-group-header' . $add_class . ' ">' ;
    
        if ( $day_group && ! empty( $date_diff['day'] ) ) { 
            
            $add_day = TRUE ; } else { $add_day = FALSE ; 
            
            }
        if ( $week_group && ! empty( $date_diff['week_start'] ) ) { 
            
            $add_week = TRUE ; 
            
        } else { 
                
            $add_week = FALSE ; 
            
        }
        
        if ( $month_group && ! empty( $date_diff['month'] ) ) { 
            
            $add_month = TRUE ; 
            
        } else { 
            
            $add_month = FALSE ; 
            
        }
        if ( $year_group && ! empty( $date_diff['year'] ) ) { 
            
            $add_year = TRUE ; 
            
        } else { 
            
            $add_year = FALSE ; 
            
        }

        if ( $add_year ) {

            $date_group_header .= '<span class="cks_lp-year">' . 
                    $new_date_array['year'] . '</span>' ;

        }

        if ( $add_month ) {

            $date_group_header .= '<span class="cks_lp-month">' . 
                    $new_date_array['month'] . '</span>' ;  

        }
        
        if ( $add_week ) {

            $date_group_header .= '<span class="cks_lp-week">' . 
                                sprintf( $week_title, 
                                    $new_date_array['week_start'], 
                                    $new_date_array['week_end'] ) 
                                . '</span>' ;

        }

        if ( $add_day ) {

            $date_group_header .= '<span class="cks_lp-day">' . 
                    $new_date_array['day'] . '</span>' ; 

        }

        $date_group_header .= '</div>' ;
            
    return apply_filters( 'cks_lp_date_group_header', $date_group_header ) ; 
    
}

/**
 * DEFINE WEEK FOR WEEK OF HEADERS
 * modified from Stack Overflow http://stackoverflow.com/a/20622278/3692443
 * @param numerical $week
 * @param numerical $year
 * @return array
 */
function cks_lpa_getStartAndEndDate($week, $year, $format) {

    $dto = new DateTime();
    $dto->setISODate( $year, $week );
    $ret['week_start'] = $dto->format( $format );
    $dto->modify( '+6 days' );
    $ret['week_end'] = $dto->format( $format );
    
    return $ret;
    
}

function cks_lpa_add_thumbnail( $use_thumbnail, $source_link ) {
    
    if ( $use_thumbnail ) {
        
        echo '<div class="cks_lp-thumbnail">' ;
        
        if (has_post_thumbnail() ) { 
            
            $size = 'thumbnail' ;
            
            $thumbnail_img = get_the_post_thumbnail( '', $size ) ;
            
            $thumbnail_html =  '<a class="cks_lp-title-thumbnail-link" href="' 
                . $source_link . '" title="' 
                . __( 'Go to ', 'cks_lpa' ) 
                . get_the_title() 
                . '" alt="' . get_the_title() .'" />' 
                . $thumbnail_img . '</a>' ;
            
            echo apply_filters( 'cks_lp_thumbnail' , $thumbnail_html ) ;
            
        } 
            
        echo '</div>' ;
        
    }

}